@@ -1,11 +1,22 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.0" language="uk_UA">
+<TS version="2.1" language="uk_UA">
 <context>
     <name>AudioCaptureSession</name>
     <message>
         <source>RAW file format</source>
-        <translation>Файл формату RAW</translation>
+        <translation type="vanished">Файл формату RAW</translation>
+    </message>
+    <message>
+        <source>WAV file format</source>
+        <translation type="vanished">Файл формату WAV</translation>
+    </message>
+</context>
+<context>
+    <name>AudioContainerControl</name>
+    <message>
+        <source>RAW (headerless) file format</source>
+        <translation>Файл формату RAW (без заголовку)</translation>
     </message>
     <message>
         <source>WAV file format</source>
@@ -16,7 +27,127 @@
     <name>AudioEncoderControl</name>
     <message>
         <source>PCM audio data</source>
-        <translation>Аудіо-дані PCM</translation>
+        <translation type="vanished">Аудіо-дані PCM</translation>
+    </message>
+    <message>
+        <source>Linear PCM audio data</source>
+        <translation>Лінійні аудіо-дані PCM</translation>
+    </message>
+</context>
+<context>
+    <name>BbCameraAudioEncoderSettingsControl</name>
+    <message>
+        <source>No compression</source>
+        <translation>Без стиснення</translation>
+    </message>
+    <message>
+        <source>AAC compression</source>
+        <translation>Стиснення AAC</translation>
+    </message>
+    <message>
+        <source>PCM uncompressed</source>
+        <translation>Без стиснення PCM</translation>
+    </message>
+</context>
+<context>
+    <name>BbCameraMediaRecorderControl</name>
+    <message>
+        <source>Unable to retrieve mute status</source>
+        <translation>Неможливо отримати стан вимкнення звуку</translation>
+    </message>
+    <message>
+        <source>Unable to retrieve audio input volume</source>
+        <translation>Неможливо отримати гучність вхідного звуку</translation>
+    </message>
+    <message>
+        <source>Unable to set mute status</source>
+        <translation>Неможливо встановити стан вимкнення звуку</translation>
+    </message>
+    <message>
+        <source>Unable to set audio input volume</source>
+        <translation>Неможливо встановити гучність вхідного звуку</translation>
+    </message>
+</context>
+<context>
+    <name>BbCameraSession</name>
+    <message>
+        <source>Camera provides image in unsupported format</source>
+        <translation>Камера надає зображення в форматі, що не підтримується</translation>
+    </message>
+    <message>
+        <source>Could not load JPEG data from frame</source>
+        <translation>Не вдалось завантажити дані JPEG з кадру</translation>
+    </message>
+    <message>
+        <source>Camera not ready</source>
+        <translation>Камера не готова</translation>
+    </message>
+    <message>
+        <source>Unable to apply video settings</source>
+        <translation>Неможливо застосувати налаштування відео</translation>
+    </message>
+    <message>
+        <source>Could not open destination file:
+%1</source>
+        <translation>Не вдалось відкрити файл-отримувач:
+%1</translation>
+    </message>
+    <message>
+        <source>Unable to open camera</source>
+        <translation>Неможливо відкрити камеру</translation>
+    </message>
+    <message>
+        <source>Unable to retrieve native camera orientation</source>
+        <translation>Неможливо отримати рідну орієнтацію камери</translation>
+    </message>
+    <message>
+        <source>Unable to close camera</source>
+        <translation>Неможливо закрити камеру</translation>
+    </message>
+    <message>
+        <source>Unable to start video recording</source>
+        <translation>Неможливо розпочати запис відео</translation>
+    </message>
+    <message>
+        <source>Unable to stop video recording</source>
+        <translation>Неможливо закінчити запис відео</translation>
+    </message>
+</context>
+<context>
+    <name>BbCameraVideoEncoderSettingsControl</name>
+    <message>
+        <source>No compression</source>
+        <translation>Без стиснення</translation>
+    </message>
+    <message>
+        <source>AVC1 compression</source>
+        <translation>Стиснення AVC1</translation>
+    </message>
+    <message>
+        <source>H264 compression</source>
+        <translation>Стиснення H264</translation>
+    </message>
+</context>
+<context>
+    <name>BbImageEncoderControl</name>
+    <message>
+        <source>JPEG image</source>
+        <translation>Зображення JPEG</translation>
+    </message>
+</context>
+<context>
+    <name>BbVideoDeviceSelectorControl</name>
+    <message>
+        <source>Front Camera</source>
+        <translation>Передня камера</translation>
+    </message>
+    <message>
+        <source>Rear Camera</source>
+        <translation>Задня камера</translation>
+    </message>
+    <message>
+        <source>Desktop Camera</source>
+        <translation>Камера стільниці</translation>
     </message>
 </context>
 <context>
@@ -169,6 +300,78 @@
         <translation>Довжина%1</translation>
     </message>
 </context>
+<context>
+    <name>QAndroidAudioEncoderSettingsControl</name>
+    <message>
+        <source>Adaptive Multi-Rate Narrowband (AMR-NB) audio codec</source>
+        <translation>Адаптивний вузькополосне кодування звуку зі змінною швидкістю (AMR-NB)</translation>
+    </message>
+    <message>
+        <source>Adaptive Multi-Rate Wideband (AMR-WB) audio codec</source>
+        <translation>Адаптивний широкополосне кодування звуку зі змінною швидкістю (AMR-WB)</translation>
+    </message>
+    <message>
+        <source>AAC Low Complexity (AAC-LC) audio codec</source>
+        <translation>Аудіо-кодек AAC низької складності (AAC-LC)</translation>
+    </message>
+</context>
+<context>
+    <name>QAndroidCameraSession</name>
+    <message>
+        <source>Camera not ready</source>
+        <translation>Камера не готова</translation>
+    </message>
+    <message>
+        <source>Drive mode not supported</source>
+        <extracomment>Drive mode is the camera&apos;s shutter mode, for example single shot, continuos exposure, etc.</extracomment>
+        <translation>Режим не підтримується</translation>
+    </message>
+    <message>
+        <source>Could not open destination file: %1</source>
+        <translation>Не вдалось відкрити файл-отримувач: %1</translation>
+    </message>
+</context>
+<context>
+    <name>QAndroidImageEncoderControl</name>
+    <message>
+        <source>JPEG image</source>
+        <translation>Зображення JPEG</translation>
+    </message>
+</context>
+<context>
+    <name>QAndroidMediaContainerControl</name>
+    <message>
+        <source>MPEG4 media file format</source>
+        <translation>Медіа-файл формату MPEG4</translation>
+    </message>
+    <message>
+        <source>3GPP media file format</source>
+        <translation>Медіа-файл формату 3GPP</translation>
+    </message>
+    <message>
+        <source>AMR NB file format</source>
+        <translation>Файл формату AMR NB</translation>
+    </message>
+    <message>
+        <source>AMR WB file format</source>
+        <translation>Файл формату AMR WB</translation>
+    </message>
+</context>
+<context>
+    <name>QAndroidVideoEncoderSettingsControl</name>
+    <message>
+        <source>H.263 compression</source>
+        <translation>Стиснення H.263</translation>
+    </message>
+    <message>
+        <source>H.264 compression</source>
+        <translation>Стиснення H.264</translation>
+    </message>
+    <message>
+        <source>MPEG-4 SP compression</source>
+        <translation>Стиснення MPEG-4 SP</translation>
+    </message>
+</context>
 <context>
     <name>QAudioDecoder</name>
     <message>
@@ -194,7 +397,7 @@
     <name>QCameraPrivate</name>
     <message>
         <source>The camera service is missing</source>
-        <translation>Сервіс камери відсутній</translation>
+        <translation type="obsolete">Сервіс камери відсутній</translation>
     </message>
 </context>
 <context>
